@@ -7,42 +7,43 @@
 #' @param theme apply a theme from \code{mf_theme}
 #' @export
 #' @importFrom methods is
-#' @importFrom sf st_bbox st_as_sfc st_geometry
+#' @importFrom sf st_bbox st_as_sfc st_geometry `st_crs<-`
 #' @return No return value, a map is initiated.
 #' @examples
 #' mtq <- mf_get_mtq()
 #' target <- mtq[30, ]
 #' mf_init(target)
 #' mf_map(mtq, add = TRUE)
-mf_init <- function(x,
-                    expandBB = rep(0, 4),
-                    theme) {
+mf_init <- function(x, expandBB = rep(0, 4), theme) {
   if (!missing(theme)) {
     mf_theme(theme)
   }
   mar <- .gmapsf$args$mar
   bgmap <- .gmapsf$args$bg
 
-  if (is(x, "Raster")) {
-    bb <- st_bbox(x)
-    xd <- diff(bb[c(1, 3)]) * 0.04
-    yd <- diff(bb[c(2, 4)]) * 0.04
-    nbb <- bb + c(xd, yd, -xd, -yd)
-    x <- st_as_sfc(st_bbox(nbb), crs = st_crs(x))
+  if (is(x, "SpatRaster")) {
+    if (!requireNamespace("terra", quietly = TRUE)) {
+      stop(
+        "'terra' package is needed for this function to work. Please install it.",
+        call. = FALSE
+      )
+    }
+
+    proj <- terra::crs(x)
+    bb <- terra::ext(x)[c(1, 3, 2, 4)]
+    y <- st_as_sfc(st_bbox(bb))
+    st_crs(y) <- proj
+    mf_init(y, expandBB = c(rep(-.04, 4)) + expandBB)
+    return(invisible(x))
   }
 
   # transform to bbox
   bb <- st_bbox(x)
-  y <- st_as_sfc(bb)
+  y <- st_as_sfc(bb, crs = st_crs(x))
 
   if (par("xaxs") == "r") {
     expandBB <- expandBB / (1 + 0.08)
   }
-  # expandBB mgmt
-  extra <- expandBB[c(2, 1, 4, 3)]
-  w <- bb[3] - bb[1]
-  h <- bb[4] - bb[2]
-  bb <- bb + (extra * c(-w, -h, w, h))
 
   # margins mgmt
   op <- par(mar = .gmapsf$args$mar, no.readonly = TRUE)
