@@ -5,7 +5,7 @@
 #' @param col_na color for missing values
 #' @param pos position of the legend, one of "topleft", "top",
 #' "topright", "right", "bottomright", "bottom", "bottomleft",
-#' "left" or a vector of two coordinates in map units
+#' "left", "interactive" or a vector of two coordinates in map units
 #' (c(x, y))
 #' @param val break labels
 #' @param title title of the legend
@@ -46,20 +46,13 @@ mf_legend_c <- function(pos = "topleft",
   op <- par(mar = .gmapsf$args$mar, no.readonly = TRUE)
   on.exit(par(op))
   # stop if the position is not valid
-  positions <- c(
-    "bottomleft", "left", "topleft", "top", "bottom",
-    "bottomright", "right", "topright",
-    "bottomleft1", "bottomright1", "bottom1",
-    "bottomleft2", "bottomright2", "bottom2",
-    "topright1", "topleft1", "top1",
-    "topright2", "topleft2", "top2"
-  )
   if (length(pos) == 1) {
-    if (!pos %in% positions) {
+    if (!pos %in% .gmapsf$positions) {
       return(invisible())
     }
   }
 
+
   # default values
   insetf <- strwidth("MM", units = "user", cex = 1)
   inset <- insetf * cex
